summaryrefslogtreecommitdiffstats
path: root/kmdi/kmdichildarea.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
commit10308be19ef7fa44699562cc75946e7ea1fdf6b9 (patch)
tree4bc444c00a79e88105f2cfce5b6209994c413ca0 /kmdi/kmdichildarea.h
parent307136d8eef0ba133b78ceee8e901138d4c996a1 (diff)
downloadtdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.tar.gz
tdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1212479 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmdi/kmdichildarea.h')
-rw-r--r--kmdi/kmdichildarea.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kmdi/kmdichildarea.h b/kmdi/kmdichildarea.h
index dac64cff4..37ce3336f 100644
--- a/kmdi/kmdichildarea.h
+++ b/kmdi/kmdichildarea.h
@@ -154,31 +154,31 @@ public:
/**
* Sets the MDI childframe window caption font
- * A retqlayout does not occur when using this function
+ * A relayout does not occur when using this function
*/
void setMdiCaptionFont( const TQFont &fnt );
/**
* Sets the foreground color of the active MDI childframe window caption
- * A retqlayout does not occur when using this function
+ * A relayout does not occur when using this function
*/
void setMdiCaptionActiveForeColor( const TQColor &clr );
/**
* Sets the background color of the active MDI childframe window captions
- * A retqlayout does not occur when using this function
+ * A relayout does not occur when using this function
*/
void setMdiCaptionActiveBackColor( const TQColor &clr );
/**
* Sets the foreground color of inactive MDI childframe window captions
- * A retqlayout does not occur when using this function
+ * A relayout does not occur when using this function
*/
void setMdiCaptionInactiveForeColor( const TQColor &clr );
/**
* Sets the background color of inactive MDI childframe window captions
- * A retqlayout does not occur when using this function
+ * A relayout does not occur when using this function
*/
void setMdiCaptionInactiveBackColor( const TQColor &clr );
@@ -237,9 +237,9 @@ public slots:
void tileVertically();
/**
* Position and tqlayout the minimized child frames
*/
- void tqlayoutMinimizedChildren();
+ void layoutMinimizedChildren();
protected:
@@ -249,7 +249,7 @@ protected:
void tileAllInternal( int maxWnds );
/**
- * Automatically resizes a maximized MDI view and tqlayouts the positions of minimized MDI views.
+ * Automatically resizes a maximized MDI view and layouts the positions of minimized MDI views.
*/
virtual void resizeEvent( TQResizeEvent * );
@@ -237,9 +237,9 @@ public slots:
void tileVertically();
/**
- * Position and tqlayout the minimized child frames
+ * Position and layout the minimized child frames
*/